/*
Copyright 2022.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1alpha1

import (
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
)

// EDIT THIS FILE!  THIS IS SCAFFOLDING FOR YOU TO OWN!
// NOTE: json tags are required.  Any new fields you add must have json tags for the fields to be serialized.

// OSArtifactSpec defines the desired state of OSArtifact
type OSArtifactSpec struct {
	// INSERT ADDITIONAL SPEC FIELDS - desired state of cluster
	// Important: Run "make" to regenerate code after modifying this file

	// Foo is an example field of OSArtifact. Edit osartifact_types.go to remove/update
	ImageName string `json:"imageName,omitempty"`
	ISO       bool   `json:"iso,omitempty"`
	// TODO: treat cloudconfig as a secret, and take a secretRef where to store it (optionally)
	CloudConfig string `json:"cloudConfig,omitempty"`
	GRUBConfig  string `json:"grubConfig,omitempty"`

	Bundles     []string `json:"bundles,omitempty"`
	PullOptions Pull     `json:"pull,omitempty"`
	OSRelease   string   `json:"osRelease,omitempty"`
	PushOptions Push     `json:"push,omitempty"`
}

type Push struct {
	Push                         bool               `json:"push,omitempty"`
	ImageName                    string             `json:"imageName,omitempty"`
	ContainerRegistryCredentials *SecretKeySelector `json:"containerRegistryCredentials,omitempty"`
}

type Pull struct {
	ContainerRegistryCredentials *SecretKeySelector `json:"containerRegistryCredentials,omitempty"`
}
type LocalObjectReference struct {
	Name string `json:"name"`
}

type SecretKeySelector struct {
	LocalObjectReference `json:",inline"`
	// +optional
	Namespace string `json:"namespace,omitempty"`
	// +optional
	Key string `json:"key,omitempty"`
}

// OSArtifactStatus defines the observed state of OSArtifact
type OSArtifactStatus struct {
	// INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
	// Important: Run "make" to regenerate code after modifying this file
	Phase string `json:"phase,omitempty"`
}

//+kubebuilder:object:root=true
//+kubebuilder:subresource:status

// OSArtifact is the Schema for the osartifacts API
type OSArtifact struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   OSArtifactSpec   `json:"spec,omitempty"`
	Status OSArtifactStatus `json:"status,omitempty"`
}

//+kubebuilder:object:root=true

// OSArtifactList contains a list of OSArtifact
type OSArtifactList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []OSArtifact `json:"items"`
}

func init() {
	SchemeBuilder.Register(&OSArtifact{}, &OSArtifactList{})
}
